==> user-repository-sequelize-0.1.0.tgz: package/tests/cases/uuid-user.test.ts <==
import { expect } from 'chai'
// eslint-disable-next-line import/no-extraneous-dependencies
import { v4 as uuidv4 } from 'uuid'

import { createHash } from '@goodrequest/passport-jwt-wrapper'

import { PERMISSION } from '../../src/utils/enums'
import { UserRepository, UUIDUserModel } from '../../src'

import { models } from '../db/models'
import { declareUserRepositoryTests } from '../declareTests'
import { password, userData } from '../utils/helper'

const { UserUUID } = models

/* eslint-disable @typescript-eslint/no-unused-expressions */
describe(`UUID User`, () => {
	const userRepo = new UserRepository(UserUUID)
	describe('Good seeds', () => {
		const dbUsers: UUIDUserModel[] = []

		before(async () => {
			const hash = await createHash(password)

			const mappedData = userData.map((data) => ({
				email: data.email,
				confirmedAt: data.isConfirmed ? Date.now() : null,
				hash: data.isConfirmed ? hash : null,
				permission: data.permission
			}))

			const seedUsers = await UserUUID.bulkCreate(mappedData)
			dbUsers.push(...seedUsers)
		})

		declareUserRepositoryTests(userRepo, dbUsers)
	})

	describe('Wrong seeds', () => {
		beforeEach(async () => {
			await UserUUID.truncate()
		})

		it('no seeds', async () => {
			const user = await userRepo.getUserById(uuidv4())
			expect(user).not.to.exist
		})

		it('`getUserById` More users with same email', async () => {
			const hash = await createHash(password)

			const data = {
				email: 'user@goodrequest.com',
				permission: PERMISSION.USER,
				confirmedAt: Date.now(),
				hash
			}

			const [seedUser1, seedUser2] = await UserUUID.bulkCreate([
				data,
				{
					...data,
					email: 'user@goodrequest.com'
				}
			])

			const user = await userRepo.getUserById(seedUser1.id)
			const user2 = await userRepo.getUserById(seedUser2.id)
			expect(user).to.exist
			expect(user2).to.exist
			expect(user?.id).not.to.eq(user2?.id)
			expect(user?.email).to.eq(user2?.email)
		})

		it('`getNewUserById` More users with same email', async () => {
			if (!userRepo.getNewUserById) {
				// eslint-disable-next-line @typescript-eslint/ban-ts-comment
				// @ts-ignore
				return this.skip()
			}

			const data = {
				email: 'user@goodrequest.com',
				permission: PERMISSION.USER
			}

			const [seedUser1, seedUser2] = await UserUUID.bulkCreate([
				data,
				{
					...data,
					email: 'user@goodrequest.com'
				}
			])

			const user = await userRepo.getNewUserById(seedUser1.id)
			const user2 = await userRepo.getNewUserById(seedUser2.id)
			expect(user).to.exist
			expect(user2).to.exist
			expect(user?.id).not.to.eq(user2?.id)
			return expect(user?.email).to.eq(user2?.email)
		})

		it('`getUserByEmail` More users with same email', async () => {
			const hash = await createHash(password)

			const data = {
				email: 'user@goodrequest.com',
				permission: PERMISSION.USER,
				confirmedAt: Date.now(),
				hash
			}

			const [seedUser1, seedUser2] = await UserUUID.bulkCreate([
				data,
				{
					...data,
					email: 'user@goodrequest.com'
				}
			])

			const user = await userRepo.getUserByEmail(seedUser1.email)
			const user2 = await userRepo.getUserByEmail(seedUser2.email)
			expect(user).to.exist
			expect(user2).to.exist
			expect(user?.id).to.eq(user2?.id)
			expect(user?.email).to.eq(user2?.email)
		})
	})
})

==> user-repository-sequelize-0.3.0.tgz: package/tests/cases/uuid-user.test.ts <==
import { expect } from 'chai'
// eslint-disable-next-line import/no-extraneous-dependencies
import { v4 as uuidv4 } from 'uuid'

import { createHash } from '@goodrequest/passport-jwt-wrapper'

import { PERMISSION } from '../../src/utils/enums'
import { UserRepository, UUIDUserModel } from '../../src'

import { models } from '../db/models'
import { declareUserRepositoryTests } from '../declareTests'
import { password, userData } from '../utils/helper'

const { UserUUID } = models

/* eslint-disable @typescript-eslint/no-unused-expressions */
describe(`UUID User`, () => {
	const userRepo = new UserRepository(UserUUID)
	describe('Good seeds', () => {
		const dbUsers: UUIDUserModel[] = []

		before(async () => {
			const hash = await createHash(password)

			const mappedData = userData.map((data) => ({
				email: data.email,
				confirmedAt: data.isConfirmed ? Date.now() : null,
				hash: data.isConfirmed ? hash : null,
				permission: data.permission
			}))

			const seedUsers = await UserUUID.bulkCreate(mappedData)
			dbUsers.push(...seedUsers)
		})

		declareUserRepositoryTests(userRepo, dbUsers)
	})

	describe('Wrong seeds', () => {
		beforeEach(async () => {
			await UserUUID.truncate()
		})

		it('no seeds', async () => {
			const user = await userRepo.getUserById(uuidv4())
			expect(user).not.to.exist
		})

		it('`getUserById` More users with same email', async () => {
			const hash = await createHash(password)

			const data = {
				email: 'user@goodrequest.com',
				permission: PERMISSION.USER,
				confirmedAt: Date.now(),
				hash
			}

			const [seedUser1, seedUser2] = await UserUUID.bulkCreate([
				data,
				{
					...data,
					email: 'user@goodrequest.com'
				}
			])

			const user = await userRepo.getUserById(seedUser1.id)
			const user2 = await userRepo.getUserById(seedUser2.id)
			expect(user).to.exist
			expect(user2).to.exist
			expect(user?.id).not.to.eq(user2?.id)
			expect(user?.email).to.eq(user2?.email)
		})

		it('`getNewUserById` More users with same email', async function test() {
			if (!userRepo.getNewUserById) {
				return this.skip()
			}

			const data = {
				email: 'user@goodrequest.com',
				permission: PERMISSION.USER
			}

			const [seedUser1, seedUser2] = await UserUUID.bulkCreate([
				data,
				{
					...data,
					email: 'user@goodrequest.com'
				}
			])

			const user = await userRepo.getNewUserById(seedUser1.id)
			const user2 = await userRepo.getNewUserById(seedUser2.id)
			expect(user).to.exist
			expect(user2).to.exist
			expect(user?.id).not.to.eq(user2?.id)
			return expect(user?.email).to.eq(user2?.email)
		})

		it('`getUserByEmail` More users with same email', async () => {
			const hash = await createHash(password)

			const data = {
				email: 'user@goodrequest.com',
				permission: PERMISSION.USER,
				confirmedAt: Date.now(),
				hash
			}

			const [seedUser1, seedUser2] = await UserUUID.bulkCreate([
				data,
				{
					...data,
					email: 'user@goodrequest.com'
				}
			])

			const user = await userRepo.getUserByEmail(seedUser1.email)
			const user2 = await userRepo.getUserByEmail(seedUser2.email)
			expect(user).to.exist
			expect(user2).to.exist
			expect(user?.id).to.eq(user2?.id)
			expect(user?.email).to.eq(user2?.email)
		})
	})
})
